.. _api-mixins:

Mixins
======

.. versionadded:: 1.0.4


.. automodule:: guardian.mixins


.. mixin:: LoginRequiredMixin

LoginRequiredMixin
------------------

.. autoclass:: guardian.mixins.LoginRequiredMixin
   :members:


.. mixin:: PermissionRequiredMixin

PermissionRequiredMixin
-----------------------

.. autoclass:: guardian.mixins.PermissionRequiredMixin
   :members:

